@@ -279,7 +279,7 @@ def add_thesaurus(session, name, title, organisation, url, description=None, uui
     return add_record(session, tablename='thesaurus', **attr)
 
 
-def add_person(session, first_name, last_name, organisation_name=None, affiliation=None, attribution=None):
+def add_person(session, first_name, last_name, organisation_name=None, organisation_abbrev=None, affiliation=None, attribution=None):
     r"""Add new Person
 
     Add a new Person to the database. A person can be a real Person
@@ -298,9 +298,13 @@ def add_person(session, first_name, last_name, organisation_name=None, affiliati
         A real persions last name. If first_name is NULL, 
         last_name is assumned to be an institution.
     organisation_name : str
-        .. versionadded: 0.1.10
+        .. versionadded:: 0.1.10
         Optional, but **highly_recommended** if applicable. Name of
         the head institution, whithout department.
+    organisation_abbrev : str
+        .. versionadded:: 0.2.6
+        Optional, abbreviated version of the Institution. I.e. the 
+        famous Karlsruhe Institute of Technology is better known as 'KIT'
     affiliation : str
         Affiliation if applicable. Has to go into a single string
         of 1024 bytes. Full attribution including department and group name.
@@ -312,12 +316,64 @@ def add_person(session, first_name, last_name, organisation_name=None, affiliati
     -------
     entry: metacatalog.Person
         Entry instance of the added Person entity
+
+    See Also
+    --------
+    add_organisation
   
     """
     attr = dict(
+        is_organisation=False,
         first_name=first_name, 
         last_name=last_name,
         organisation_name=organisation_name, 
+        organisation_abbrev=organisation_abbrev,
+        affiliation=affiliation,
+        attribution=attribution
+    )
+
+    return add_record(session=session, tablename='persons', **attr)
+
+
+def add_organisation(session, organisation_name, organisation_abbrev=None, affiliation=None, attribution=None):
+    r"""Add new Organisation
+    .. versionadded:: 0.2.6
+
+    Add a new Organisation to the database. This is internally handled as a 
+    Person, but with ``is_organisation==True``.
+
+    Parameters
+    ----------
+   session : sqlalchemy.Session
+        SQLAlchemy session connected to the database.
+    organisation_name : str
+        Required. Name of the head institution, whithout department.
+    organisation_abbrev : str
+        Optional, abbreviated version of the Institution. I.e. the 
+        famous Karlsruhe Institute of Technology is better known as 'KIT'
+    affiliation : str
+        Affiliation if applicable. Has to go into a single string
+        of 1024 bytes. Full attribution including department and group name.
+    attribution : str.
+        Optional. Attribution recommondation for all datasets 
+        this Person is associated to as a first author.
+    
+    Returns
+    -------
+    entry: metacatalog.Person
+        Entry instance of the added Person entity
+
+    See Also
+    --------
+    add_person
+  
+    """
+    attr = dict(
+        is_organisation=True,
+        first_name=None,
+        last_name=None,
+        organisation_name=organisation_name,
+        organisation_abbrev=organisation_abbrev,
         affiliation=affiliation,
         attribution=attribution
     )
