@@ -1,9 +1,11 @@
 from . import (
     rev0,
     rev1,
+    rev2,
 )
 
 revisions = {
     0: rev0,
     1: rev1,
+    2: rev2,
 }
